@@ -31,11 +31,17 @@ class Dashboard:
 
     def get_name(self):
         """Gets the dashboard's title"""
-        return self._dashboard_json['title']
+        if 'title' in self._dashboard_json:
+            return self._dashboard_json['title']
+        else:
+            return None
 
     def get_dashboard_folder(self):
         """Gets the dashboards folder"""
-        return self._py_client.get_folder_by_id(self._dashboard_json['parentFolder'])
+        if 'parentFolder' in self._dashboard_json:
+            return self._py_client.get_folder_by_id(self._dashboard_json['parentFolder'])
+        else:
+            return None
 
     def get_shares(self):
         """Gets the dashboard shares json """
